@@ -29,7 +29,8 @@ class ArgsContainer(object):
 
     def _check_track_name(self, lib, tracks, strand):
         if lib.split("/")[-1] in tracks["file"]:
-            print("Error: Some filenames of the wiggle files are repeated!")
+            print("Error: {0} of the wiggle files is repeated!".format(
+                  lib.split("/")[-1]))
             sys.exit()
         else:
             tracks["file"].append(lib.split("/")[-1])
@@ -39,8 +40,8 @@ class ArgsContainer(object):
                 if line.startswith("track"):
                     track_name = line.split(" ")[-1]
                     if track_name in tracks["track"][strand]:
-                        print("Error: Some names of the tracks in the "
-                              "wiggle files are repeated!")
+                        print("Error: {0} of the tracks in the "
+                              "wiggle files is repeated!".format(track_name))
                         sys.exit()
                     else:
                         tracks["track"][strand].append(track_name) 
@@ -50,6 +51,10 @@ class ArgsContainer(object):
         if libs is not None:
             self.helper.check_make_folder(wig_folder)
             for lib in libs:
+                if not os.path.exists(lib.split(":")[0]):
+                    print("Error: {0} of the wiggle files is not found!".format(
+                          lib.split(":")[0]))
+                    sys.exit()
                 self._check_track_name(lib.split(":")[0], tracks,
                                        lib.split(":")[-1])
                 shutil.copy(lib.split(":")[0], wig_folder)
@@ -140,7 +145,7 @@ class ArgsContainer(object):
         for lib in libs:
             datas = lib.split(":")
             if not datas[0].endswith(".wig"):
-                print("Error: The input wiggle files should end with .wig!")
+                print("Error: {0} should end with .wig!".format(datas[0]))
                 sys.exit()
             if (datas[1] != "notex") and (
                     datas[1] != "tex") and (
@@ -248,9 +253,11 @@ class ArgsContainer(object):
                             os.path.join(merge_folder,
                                          strain + "_reverse.wig"))
             else:
-                print("Error: .wig files is not compose of "
-                      "forward or reverse files or the Seq IDs are no "
-                      "consistent in all gff and fasta files.")
+                print("Error: comparing input files of {0} failed. "
+                      "Please check the seq IDs of all gff and fasta "
+                      "files, they should be the same.\nPlease also "
+                      "check the wiggle files which should contain "
+                      "forward and reverse files.".format(strain))
                 sys.exit()
         self.helper.remove_all_content(wig_path, ".wig", "file")
         self.helper.move_all_content(merge_folder, wig_path, None)
@@ -366,15 +373,48 @@ class ArgsContainer(object):
                         if file_.endswith(type_):
                             detect = True
                 if not detect:
-                    print("Error: Some files don't exist in {0} or "
+                    print("Error: {0} doesn't exist or "
                           "the {0} is/are not ended with {1}!".format(
-                          " and ".join(flag), " ".join(file_types)))
+                          files, " ".join(file_types)))
                     sys.exit()
                 shutil.copy(file_, new_ref_folder)
+                if (file_.endswith(".gff3")):
+                    new_name = os.path.basename(file_)[:-1]
+                    shutil.move(os.path.join(new_ref_folder, os.path.basename(file_)),
+                                 os.path.join(new_ref_folder, new_name))
             return new_ref_folder
         else:
             return None
 
+    def _check_tss_parameter_setting(
+            self, auto_load, genome_order, height, height_reduction, factor,
+            factor_reduction, base_height, enrichment_factor,
+            processing_factor):
+        if auto_load:
+            if not os.path.exists(auto_load):
+                print("Error: {0} is not found. Please assign proper folder to "
+                      "--auto_load_optimized_parameters!".format(auto_load))
+                sys.exit()
+        else:
+            para_lists = [height, height_reduction, factor, factor_reduction,
+                          base_height, enrichment_factor, processing_factor]
+            para_names = ["--height", "--height_reduction", "--factor",
+                        "--factor_reduction", "--base_height",
+                        "--enrichment_factor", "--processing_factor"]
+            if (genome_order is not None):
+                for para_list, para_name in zip(para_lists, para_names):
+                    if len(genome_order) != len(para_list):
+                        print("Error: --genome_order and {0} have different number of "
+                              "of genomes!".format(para_name))
+                        sys.exit()
+            else:
+                for para_list, para_name in zip(para_lists, para_names):
+                    if len(para_list) != 1:
+                        print("Error: --genome_order is default (using one "
+                              "parameter set to all genomes) but {0} has more "
+                              "than 1 input values!".format(para_name))
+                        sys.exit()
+
     def container_ratt(self, ratt_path, element, transfer_type,
                        ref_embl, ref_gbk, target_fasta, ref_fasta, ratt_folder,
                        tar_annotation_folder, compare_pair):
@@ -401,8 +441,9 @@ class ArgsContainer(object):
 
     def container_tsspredator(self, TSSpredator_path, compute_program,
                               fasta_files, annotation_files, lib,
-                              output_prefix, height, height_reduction, factor,
-                              factor_reduction, base_height, enrichment_factor,
+                              output_prefix, auto_load, genome_order, height,
+                              height_reduction, factor, factor_reduction,
+                              base_height, enrichment_factor,
                               processing_factor, replicate_match, out_folder,
                               validate_gene, merge_manual, strain_lengths,
                               compare_transcript_assembly, fuzzy, utr_length,
@@ -418,11 +459,14 @@ class ArgsContainer(object):
                 self.strain_lengths = {"all": "all"}
         self.tsspredator_path = TSSpredator_path
         self.program = compute_program
+        self._check_tss_parameter_setting(
+            auto_load, genome_order, height, height_reduction, factor,
+            factor_reduction, base_height, enrichment_factor, processing_factor)
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], out_folder, "tmp_fasta", fasta_files,
                 ["--fasta_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], out_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.wig_folder = os.path.join(out_folder, "tmp_wig")
         self.helper.check_make_folder(self.wig_folder)
@@ -432,6 +476,8 @@ class ArgsContainer(object):
         self.libs = self._check_libs(self.libs, None)
         self._check_condition_num(output_prefix, self.libs)
         self.output_prefixs = output_prefix
+        self.auto_load = auto_load
+        self.genome_order = genome_order
         self.height = height
         self.height_reduction = height_reduction
         self.factor = factor
@@ -443,10 +489,10 @@ class ArgsContainer(object):
         self.out_folder = out_folder
         self.validate = validate_gene
         self.manual = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_manual", merge_manual,
+                [".gff", ".gff3"], out_folder, "tmp_manual", merge_manual,
                 ["--manual_files_lengths"])
         self.ta_files = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_ta", compare_transcript_assembly,
+                [".gff", ".gff3"], out_folder, "tmp_ta", compare_transcript_assembly,
                 ["--compare_transcript_assembly"])
         self.fuzzy = fuzzy
         self.utr_length = utr_length
@@ -454,7 +500,7 @@ class ArgsContainer(object):
         self.check_orphan = re_check_orphan
         self.overlap_feature = overlap_feature
         self.overlap_gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_reference", overlap_gff,
+                [".gff", ".gff3"], out_folder, "tmp_reference", overlap_gff,
                 ["--compare_overlap_gff"])
         self.remove_low_expression = remove_low_expression
         return self
@@ -479,10 +525,10 @@ class ArgsContainer(object):
                 [".fa", ".fna", ".fasta"], out_folder, "tmp_fasta",
                 fasta_file, ["--fasta_files"])
         self.manuals = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_manual",
+                [".gff", ".gff3"], out_folder, "tmp_manual",
                 manual, ["--manual_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_anno",
+                [".gff", ".gff3"], out_folder, "tmp_anno",
                 annotation_file, ["--annotation_files"])
         self.wigs = os.path.join(out_folder, "tmp_wig")
         self.helper.check_make_folder(self.wigs)
@@ -533,13 +579,13 @@ class ArgsContainer(object):
                 [".fa", ".fna", ".fasta"], out_folder, "tmp_fasta", fasta_files,
                 ["--fasta_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], out_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.trans = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_ta", transcript_files,
+                [".gff", ".gff3"], out_folder, "tmp_ta", transcript_files,
                 ["--transcript_files"])
         self.srnas = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_srna", srna, ["srna_files"])
+                [".gff", ".gff3"], out_folder, "tmp_srna", srna, ["srna_files"])
         self.helper.check_make_folder(os.path.join(out_folder, "tmp_wig"))
         self.tex_wigs = self._create_wig_folder(
                 os.path.join(out_folder, "tmp_wig", "tex_notex"),
@@ -609,7 +655,7 @@ class ArgsContainer(object):
         self.tex = tex_notex
         self.length = length
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], out_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.height = height
         self.width = width
@@ -622,7 +668,7 @@ class ArgsContainer(object):
                 tex_treated_libs, fragmented_libs)
         self.out_folder = out_folder
         self.compare_tss = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_tss", tss_files, ["--tss_files"])
+                [".gff", ".gff3"], out_folder, "tmp_tss", tss_files, ["--tss_files"])
         self.fuzzy = TSS_fuzzy
         tracks = {"file": [], "track": {"+": [], "-": []}}
         self.tlibs = self._create_working_wigs(
@@ -632,7 +678,7 @@ class ArgsContainer(object):
         self.libs = self._check_libs(self.tlibs, self.flibs)
         self.c_feature = compare_feature_genome
         self.terms = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_term", terminator_files,
+                [".gff", ".gff3"], out_folder, "tmp_term", terminator_files,
                 ["--terminator_files"])
         self.fuzzy_term = fuzzy_term
         self.max_dist = max_dist
@@ -642,17 +688,17 @@ class ArgsContainer(object):
     def container_utr(self, tss_files, annotation_files,
                       transcript_assembly_files, terminator_files,
                       terminator_fuzzy, utr_folder, tss_source, base_5utr,
-                      length, base_3utr, fuzzy_3utr, fuzzy_5utr):
+                      length, base_3utr):
         self.tsss = self._gen_copy_new_folder(
-                [".gff"], utr_folder, "tmp_tss", tss_files, ["--tss_files"])
+                [".gff", ".gff3"], utr_folder, "tmp_tss", tss_files, ["--tss_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], utr_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], utr_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.trans = self._gen_copy_new_folder(
-                [".gff"], utr_folder, "tmp_ta", transcript_assembly_files,
+                [".gff", ".gff3"], utr_folder, "tmp_ta", transcript_assembly_files,
                 ["--transcript_files"])
         self.terms = self._gen_copy_new_folder(
-                [".gff"], utr_folder, "tmp_term", terminator_files,
+                [".gff", ".gff3"], utr_folder, "tmp_term", terminator_files,
                 ["--terminator_files"])
         self.fuzzy = terminator_fuzzy
         self.out_folder = utr_folder
@@ -660,8 +706,6 @@ class ArgsContainer(object):
         self.base_5utr = base_5utr
         self.base_3utr = base_3utr
         self.length = length
-        self.fuzzy_3utr = fuzzy_3utr
-        self.fuzzy_5utr = fuzzy_5utr
         return self
 
     def container_srna(self, rnafold, relplot_pl, mountain_pl, blastn, blastx,
@@ -709,12 +753,12 @@ class ArgsContainer(object):
         else:
             self.blast_score_n = blast_score_n
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], srna_folder, "temp_anno", annotation_files,
+                [".gff", ".gff3"], srna_folder, "temp_anno", annotation_files,
                 ["--annotation_files"])
         self.tss_folder = self._gen_copy_new_folder(
-                [".gff"], srna_folder, "temp_tss", TSS_files, ["--tss_files"])
+                [".gff", ".gff3"], srna_folder, "temp_tss", TSS_files, ["--tss_files"])
         self.trans = self._gen_copy_new_folder(
-                [".gff"], srna_folder, "temp_ta", transcript_files,
+                [".gff", ".gff3"], srna_folder, "temp_ta", transcript_files,
                 ["--transcript_files"])
         self.fuzzy_inter_tss = TSS_intergenic_fuzzy
         self.fuzzy_5utr_tss = TSS_5UTR_fuzzy
@@ -732,7 +776,7 @@ class ArgsContainer(object):
         self.frag_wigs = self._create_wig_folder(
                 os.path.join(srna_folder, "temp_wig", "frag"), frag_libs)
         self.pro_folder = self._gen_copy_new_folder(
-                [".gff"], srna_folder, "temp_pro", processing_site_files,
+                [".gff", ".gff3"], srna_folder, "temp_pro", processing_site_files,
                 ["--processing_site_files"])
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], srna_folder,
@@ -793,15 +837,15 @@ class ArgsContainer(object):
         self.fuzzy_utr = fuzzy_utr
         self.nr_hits_num = cutoff_nr_hit
         self.sorf_file = self._gen_copy_new_folder(
-                [".gff"], srna_folder, "temp_sorf", sORF, ["--sorf_files"])
+                [".gff", ".gff3"], srna_folder, "temp_sorf", sORF, ["--sorf_files"])
         self.cutoff_overlap = overlap_percent_CDS
         self.terms = self._gen_copy_new_folder(
-                [".gff"], srna_folder, "temp_term", terminator_files,
+                [".gff", ".gff3"], srna_folder, "temp_term", terminator_files,
                 ["--terminator_files"])
         self.fuzzy_b = terminator_fuzzy_in_sRNA
         self.fuzzy_a = terminator_fuzzy_out_sRNA
         self.hypo = ignore_hypothetical_protein
-        self.tss_source = TSS_source
+        self.source = TSS_source
         self.min_utr = min_utr_coverage
         self.promoter_table = self._combine_files(
                 promoter_tables, srna_folder, "tmp_promoter_table")
@@ -811,6 +855,8 @@ class ArgsContainer(object):
         self.rank_promoter = ranking_promoter
         self.promoter_name = promoter_name
         self = self._parser_combine_wigs("srna")
+        if (not TSS_source) and (tex_notex_libs is not None):
+            self.input_libs = self.tlibs
         return self
 
     def container_intersrna(self, file_type, files, args_srna, prefix,
@@ -833,7 +879,7 @@ class ArgsContainer(object):
             args_srna.output_file = files["frag_gff"]
             args_srna.output_table = files["frag_csv"]
             args_srna.cutoffs = args_srna.coverage_frag
-            args_srna.tss_source = True
+            args_srna.source = args_srna.source
             args_srna.cut_notex = args_srna.coverage_frag
             args_srna.anti_notex_cutoff = None
         else:
@@ -846,7 +892,7 @@ class ArgsContainer(object):
             args_srna.output_file = files["tex_gff"]
             args_srna.output_table = files["tex_csv"]
             args_srna.cutoffs = args_srna.coverage_tex
-            args_srna.tss_source = args_srna.tss_source
+            args_srna.source = args_srna.source
             args_srna.cut_notex = args_srna.coverage_notex
             args_srna.anti_notex_cutoff = args_srna.anti_cover_notex
         return args_srna
@@ -928,23 +974,26 @@ class ArgsContainer(object):
                        cutoff_antisense_coverage, cutoff_5utr_coverage,
                        cutoff_3utr_coverage, cutoff_interCDS_coverage,
                        fasta_files, tex_notex_libs, frag_libs, tex_notex,
-                       replicates_tex, replicates_frag,
-                       sRNA_files, start_codon, stop_codon, cutoff_background,
+                       replicates_tex, replicates_frag, sRNA_files,
+                       start_codon, stop_codon, cutoff_background, rbs_seq,
                        fuzzy_rbs, rbs_not_after_TSS, print_all_combination,
                        best_no_sRNA, best_no_TSS, ignore_hypothetical_protein,
-                       min_rbs_distance, max_rbs_distance, extend_3, extend_5):
+                       min_rbs_distance, max_rbs_distance, extend_3, extend_5,
+                       multi_stop):
+        self.multi_stop = multi_stop
         self.out_folder = sorf_folder
+        self.rbs_seq = rbs_seq
         self.extend_3 = extend_3
         self.extend_5 = extend_5
         self.utr_detect = UTR_derived_sORF
         self.trans = self._gen_copy_new_folder(
-                [".gff"], sorf_folder, "temp_ta", transcript_files,
+                [".gff", ".gff3"], sorf_folder, "temp_ta", transcript_files,
                 ["--transcript_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], sorf_folder, "temp_anno", annotation_files,
+                [".gff", ".gff3"], sorf_folder, "temp_anno", annotation_files,
                 ["--annotation_files"])
         self.tsss = self._gen_copy_new_folder(
-                [".gff"], sorf_folder, "temp_tss", TSS_files, ["--tss_files"])
+                [".gff", ".gff3"], sorf_folder, "temp_tss", TSS_files, ["--tss_files"])
         self.utr_length = utr_length
         self.min_len = min_length
         self.max_len = max_length
@@ -974,7 +1023,7 @@ class ArgsContainer(object):
         self.replicates = self._check_replicates(
                 replicates_tex, replicates_frag, tex_notex_libs, frag_libs)
         self.srnas = self._gen_copy_new_folder(
-                [".gff"], sorf_folder, "temp_srna", sRNA_files,
+                [".gff", ".gff3"], sorf_folder, "temp_srna", sRNA_files,
                 ["--srna_files"])
         self.start_codon = start_codon
         self.stop_codon = stop_codon
@@ -1006,14 +1055,23 @@ class ArgsContainer(object):
         self.rnaup_path = rnaup_path
         self.intarna_path = intarna_path
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], starget_output_folder, "tmp_anno",
+                [".gff", ".gff3"], starget_output_folder, "tmp_anno",
                 annotation_files, ["--annotation_files"])
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], starget_output_folder,
                 "tmp_fasta", fasta_files, ["--fasta_files"])
         self.srnas = self._gen_copy_new_folder(
-                [".gff"], starget_output_folder, "tmp_srna", sRNA_files,
+                [".gff", ".gff3"], starget_output_folder, "tmp_srna", sRNA_files,
                 ["--srna_files"])
+        if "all" not in query_sRNA:
+            for q in query_sRNA:
+                data = q.split(":")
+                if (len(data) == 4) and (isinstance(data[1], int)) and (
+                        isinstance(data[2], int)):
+                    pass
+                else:
+                    print("Error: the --query_srna does not be assigned properly!\n")
+                    sys.exit()
         self.query = query_sRNA
         self.program = program
         self.inter_length = interaction_length
@@ -1045,14 +1103,14 @@ class ArgsContainer(object):
     def container_goterm(self, annotation_files, goterm_output_folder,
                          UniProt_id, go_obo, goslim_obo, transcript_files):
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], goterm_output_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], goterm_output_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.out_folder = goterm_output_folder
         self.uniprot = UniProt_id
         self.go = go_obo
         self.goslim = goslim_obo
         self.trans = self._gen_copy_new_folder(
-                [".gff"], goterm_output_folder, "tmp_ta", transcript_files,
+                [".gff", ".gff3"], goterm_output_folder, "tmp_ta", transcript_files,
                 ["--transcript_files"])
         return self
 
@@ -1061,7 +1119,7 @@ class ArgsContainer(object):
                            sublocal_output_folder, transcript_files):
         self.psortb_path = Psortb_path
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], sublocal_output_folder, "tmp_anno",
+                [".gff", ".gff3"], sublocal_output_folder, "tmp_anno",
                 annotation_files, ["--annotation_files"])
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], sublocal_output_folder,
@@ -1070,7 +1128,7 @@ class ArgsContainer(object):
         self.fuzzy = difference_multi
         self.out_folder = sublocal_output_folder
         self.trans = self._gen_copy_new_folder(
-                [".gff"], sublocal_output_folder, "tmp_ta",
+                [".gff", ".gff3"], sublocal_output_folder, "tmp_ta",
                 transcript_files, ["--transcript_files"])
         return self
 
@@ -1078,7 +1136,7 @@ class ArgsContainer(object):
                       without_strain_pubmed, species_STRING, score,
                       ppi_output_folder, node_size, query):
         self.ptts = self._gen_copy_new_folder(
-                [".gff"], ppi_output_folder, "temp_anno",
+                [".gff", ".gff3"], ppi_output_folder, "temp_anno",
                 annotation_files, ["--annotation_files"])
         self.strains = proteinID_strains
         self.no_specific = without_strain_pubmed
@@ -1092,7 +1150,7 @@ class ArgsContainer(object):
     def container_promoter(self, MEME_path, GLAM2_path, out_folder, tex_libs,
                            TSS_files, fasta_files, num_motif, nt_before_TSS,
                            motif_width, TSS_source, annotation_files, end_run,
-                           combine_all, e_value, para, program):
+                           combine_all, e_value, para, program, use_tss_type):
         self.meme_path = MEME_path
         self.glam2_path = GLAM2_path
         self.program = program
@@ -1104,7 +1162,7 @@ class ArgsContainer(object):
             sys.exit()
         self.output_folder = out_folder
         self.tsss = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_tss", TSS_files, ["--tss_files"])
+                [".gff", ".gff3"], out_folder, "tmp_tss", TSS_files, ["--tss_files"])
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], out_folder, "tmp_fasta",
                 fasta_files, ["--fasta_files"])
@@ -1115,21 +1173,18 @@ class ArgsContainer(object):
         self.tex_wigs = None
         self.frag_wigs = None
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], out_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.combine = combine_all
         self.e_value = e_value
         self.para = para
+        self.use_tss = use_tss_type
         if not TSS_source:
-            if tex_libs is None:
+            if annotation_files is None:
                 print("Error: if --tss_source is False, please assign "
-                      "--tex_libs and --annotation_files as well!")
+                      "--annotation_files as well!")
                 sys.exit()
-            else:
-                if annotation_files is None:
-                    print("Error: if --tss_source is False, please assign "
-                          "--tex_libs and --annotation_files as well!")
-                    sys.exit()
+            if tex_libs is not None:
                 self.helper.check_make_folder(os.path.join(
                     out_folder, "tmp_wig"))
                 self.tex_wigs = self._create_wig_folder(
@@ -1147,16 +1202,16 @@ class ArgsContainer(object):
                          term_files, TSS_fuzzy, term_fuzzy, min_length,
                          operon_output_folder, operon_statistics_folder):
         self.tsss = self._gen_copy_new_folder(
-                [".gff"], operon_output_folder, "tmp_tss",
+                [".gff", ".gff3"], operon_output_folder, "tmp_tss",
                 TSS_files, ["--tss_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], operon_output_folder, "tmp_anno",
+                [".gff", ".gff3"], operon_output_folder, "tmp_anno",
                 annotation_files, ["--annotation_files"])
         self.trans = self._gen_copy_new_folder(
-                [".gff"], operon_output_folder, "tmp_ta",
+                [".gff", ".gff3"], operon_output_folder, "tmp_ta",
                 transcript_files, ["--transcript_files"])
         self.terms = self._gen_copy_new_folder(
-                [".gff"], operon_output_folder, "tmp_term",
+                [".gff", ".gff3"], operon_output_folder, "tmp_term",
                 term_files, ["--term_files"])
         self.tss_fuzzy = TSS_fuzzy
         self.term_fuzzy = term_fuzzy
@@ -1205,7 +1260,7 @@ class ArgsContainer(object):
                 [".fa", ".fna", ".fasta"], out_folder, "tmp_fa", fasta_files,
                 ["--fasta_files"])
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], out_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], out_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.bams = bam_files
         self.read_files = read_files
@@ -1224,8 +1279,11 @@ class ArgsContainer(object):
                         riboswitch_ID, annotation_files, fasta_files,
                         tss_files, transcript_files, Rfam, ribos_output_folder,
                         thermo_output_folder, cutoff, output_all,
-                        database_folder, fuzzy, fuzzy_rbs, UTR_length):
+                        database_folder, fuzzy, without_rbs, rbs_seq,
+                        fuzzy_rbs, UTR_length):
         self.program = program
+        self.without_rbs = without_rbs
+        self.rbs_seq = rbs_seq
         if (program.lower() == "riboswitch") or (
                 program.lower() == "both"):
             output = ribos_output_folder
@@ -1236,15 +1294,15 @@ class ArgsContainer(object):
         self.cmpress_path = cmpress_path
         self.ribos_id = riboswitch_ID
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], output, "temp_anno", annotation_files,
+                [".gff", ".gff3"], output, "temp_anno", annotation_files,
                 ["--annotation_files"])
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], output, "temp_fa",
                 fasta_files, ["--fasta_files"])
         self.tsss = self._gen_copy_new_folder(
-                [".gff"], output, "temp_tss", tss_files, ["--tss_files"])
+                [".gff", ".gff3"], output, "temp_tss", tss_files, ["--tss_files"])
         self.trans = self._gen_copy_new_folder(
-                [".gff"], output, "temp_ta", transcript_files,
+                [".gff", ".gff3"], output, "temp_ta", transcript_files,
                 ["--transcript_files"])
         self.rfam = Rfam
         self.ribos_out_folder = ribos_output_folder
@@ -1262,7 +1320,7 @@ class ArgsContainer(object):
                        Max_length_repeat, min_length_spacer, Max_length_spacer,
                        cris_out_folder, ignore_hypo):
         self.gffs = self._gen_copy_new_folder(
-                [".gff"], cris_out_folder, "tmp_anno", annotation_files,
+                [".gff", ".gff3"], cris_out_folder, "tmp_anno", annotation_files,
                 ["--annotation_files"])
         self.fastas = self._gen_copy_new_folder(
                 [".fa", ".fna", ".fasta"], cris_out_folder, "tmp_fa",
